@@ -6,9 +6,11 @@ from public_api_server_connector.api.api_keys_api import ApiKeysApi
 from public_api_server_connector.api.api_logs_api import ApiLogsApi
 from public_api_server_connector.api.api_spec_api import ApiSpecApi
 from public_api_server_connector.api.courses_api import CoursesApi
+from public_api_server_connector.api.general_api import GeneralApi
 from public_api_server_connector.api.health_api import HealthApi
-from public_api_server_connector.api.ipn_api import IpnApi
 from public_api_server_connector.api.jwt_token_auth_api import JwtTokenAuthApi
+from public_api_server_connector.api.mediastorage_api import MediastorageApi
+from public_api_server_connector.api.orders_api import OrdersApi
 from public_api_server_connector.api.specification_api import SpecificationApi
 from public_api_server_connector.api.v1_api import V1Api
 
